@@ -33,7 +33,8 @@
 #include "gap_vex_exec.h"
 #include "gap_vex_dialog.h"
 #include "gap_audio_wav.h"
-
+#include "gap_audio_extract.h"
+#include "gap_bluebox.h"
 
 /* -------------------
  * p_gap_set_framerate
@@ -58,150 +59,106 @@ p_gap_set_framerate(gint32 image_id, gdouble framerate)
 }  /* end p_gap_set_framerate */
 
 
-
-
-/* ---------------------
- * p_extract_audio
- * ---------------------
- * - extract audio and optional save to wav file
+/* --------------------
+ * p_vex_apply_bluebox
+ * --------------------
+ * apply bluebox settings on the specified layer
  */
-void
-p_extract_audio(GapVexMainGlobalParams *gpp,  t_GVA_Handle   *gvahand, gdouble samples_to_read,  gboolean wav_save)
+static void
+p_vex_apply_bluebox(gint32 layer_id
+                  )
 {
-#ifdef GAP_ENABLE_VIDEOAPI_SUPPORT
-   int l_audio_channels;
-   int l_sample_rate;
-   long l_audio_samples;
-   unsigned short *left_ptr;
-   unsigned short *right_ptr;
-   unsigned short *l_lptr;
-   unsigned short *l_rptr;
-   long   l_to_read;
-   gint64 l_left_to_read;
-   long   l_block_read;
-   gdouble l_progress;
-   FILE  *fp_wav;
+  GapBlueboxGlobalParams *bbp;
+  /* blubox parameters are not provided by the caller.
+   * in this case we init with default values and try to fetch
+   * values from previous bluebox filter runs
+   */
+  bbp = gap_bluebox_bbp_new(layer_id);;
 
-   l_audio_channels = gvahand->audio_cannels;
-   l_sample_rate    = gvahand->samplerate;
-   l_audio_samples  = gvahand->total_aud_samples;
-
-   if(gap_debug)
-   {
-     printf("Channels:%d samplerate:%d samples:%d  samples_to_read: %.0f\n"
-          , (int)l_audio_channels
-          , (int)l_sample_rate
-          , (int)l_audio_samples
-          , (float)samples_to_read
-          );
-   }
-   
-  fp_wav = NULL;
-  if(wav_save) 
+  if(bbp)
   {
-    fp_wav = g_fopen(gpp->val.audiofile, "wb");
+    bbp->image_id = gimp_drawable_get_image(layer_id);
+    bbp->drawable_id = layer_id;
+    bbp->layer_id = layer_id;
+    bbp->run_mode = GIMP_RUN_NONINTERACTIVE;
+    bbp->run_flag = TRUE;
+
+    gap_bluebox_apply(bbp);
+  }
+}  /* end p_vex_apply_bluebox  */
+
+
+/* ----------------------
+ * p_frame_postprocessing
+ * ----------------------
+ * generate transpareny as alpha channel or layermask
+ * via bluebox effect (if requested)
+ */
+static void
+p_frame_postprocessing(t_GVA_Handle   *gvahand
+       ,GapVexMainGlobalParams *gpp)
+{
+  gint32 l_bbox_layer_id;
+  gint32 l_layermask_id;
+  
+  l_bbox_layer_id = gvahand->layer_id;
+  if (gpp->val.generate_alpha_via_bluebox == TRUE)
+  {
+    if ((gpp->val.extract_with_layermask == TRUE)
+    || (gpp->val.extract_with_layermask == TRUE))
+    {
+      l_bbox_layer_id = gimp_layer_copy(gvahand->layer_id);
+      gimp_image_add_layer(gvahand->image_id, l_bbox_layer_id, -1);
+
+      if(gap_debug)
+      {
+        printf("created bb_layer_id:%d\n", l_bbox_layer_id);
+      }
+      
+    }
+    if (!gimp_drawable_has_alpha(l_bbox_layer_id))
+    {
+      gimp_layer_add_alpha(l_bbox_layer_id);
+    }
+    p_vex_apply_bluebox(l_bbox_layer_id);
+  }
+
+  if (gimp_drawable_has_alpha(l_bbox_layer_id))
+  {
+    if (gpp->val.extract_alpha_as_gray_frames == TRUE)
+    {
+      l_layermask_id = gimp_layer_create_mask(l_bbox_layer_id, GIMP_ADD_ALPHA_MASK);
+      if(gap_debug)
+      {
+        printf("GRAY created layermask_id:%d\n", l_layermask_id);
+      }
+      gap_layer_copy_paste_drawable(gvahand->image_id, gvahand->layer_id, l_layermask_id);
+    } 
+    else if (gpp->val.extract_with_layermask == TRUE)
+    {
+      l_layermask_id = gimp_layer_create_mask(l_bbox_layer_id, GIMP_ADD_ALPHA_MASK);
+      if(gap_debug)
+      {
+        printf("LAYERMASK created layermask_id:%d\n", l_layermask_id);
+      }
+      gimp_layer_add_mask(gvahand->layer_id, l_layermask_id);
+    }
+
+    if (l_bbox_layer_id != gvahand->layer_id)
+    {
+      if(gap_debug)
+      {
+        printf("remove bb_layer_id:%d\n", l_bbox_layer_id);
+      }
+
+      /* remove the temporyry bluebox layer */
+      gimp_image_remove_layer(gvahand->image_id, l_bbox_layer_id);
+      //gimp_drawable_delete(l_bbox_layer_id);
+    }
   }
   
-  if((fp_wav) || (!wav_save))
-  {
-     gint32 l_bytes_per_sample;
-     gint32 l_ii;
-
-     if(l_audio_channels == 1) { l_bytes_per_sample = 2;}  /* mono */
-     else                      { l_bytes_per_sample = 4;}  /* stereo */
-
-     if(wav_save) 
-     {
-       /* write the header */
-       gap_audio_wav_write_header(fp_wav
-                      , (gint32)samples_to_read
-                      , l_audio_channels            /* cannels 1 or 2 */
-                      , l_sample_rate
-                      , l_bytes_per_sample
-                      , 16                          /* 16 bit sample resolution */
-                      );
-    }
-    if(gap_debug) printf("samples_to_read:%d\n", (int)samples_to_read);
-
-    /* audio block read (blocksize covers playbacktime for 250 frames */
-    l_left_to_read = samples_to_read;
-    l_block_read = (double)(250.0) / (double)gvahand->framerate * (double)l_sample_rate;
-    l_to_read = MIN(l_left_to_read, l_block_read);
-
-    /* allocate audio buffers */
-    left_ptr = g_malloc0((sizeof(short) * l_block_read) + 16);
-    right_ptr = g_malloc0((sizeof(short) * l_block_read) + 16);
-
-    while(l_to_read > 0)
-    {
-       l_lptr = left_ptr;
-       l_rptr = right_ptr;
-       /* read the audio data of channel 0 (left or mono) */
-       GVA_get_audio(gvahand
-                 ,l_lptr                /* Pointer to pre-allocated buffer if int16's */
-                 ,1                     /* Channel to decode */
-                 ,(gdouble)l_to_read    /* Number of samples to decode */
-                 ,GVA_AMOD_CUR_AUDIO    /* read from current audio position (and advance) */
-                 );
-      if((l_audio_channels > 1) && (wav_save))
-      {
-         /* read the audio data of channel 2 (right)
-          * NOTE: GVA_get_audio has advanced the stream position,
-          *       so we have to set GVA_AMOD_REREAD to read from
-          *       the same startposition as for channel 1 (left).
-          */
-         GVA_get_audio(gvahand
-                   ,l_rptr                /* Pointer to pre-allocated buffer if int16's */
-                   ,2                     /* Channel to decode */
-                   ,l_to_read             /* Number of samples to decode */
-                   ,GVA_AMOD_REREAD       /* read from */
-                 );
-      }
-      l_left_to_read -= l_to_read;
-
-      if(wav_save) 
-      {
-        /* write 16 bit wave datasamples 
-         * sequence mono:    (lo, hi)
-         * sequence stereo:  (lo_left, hi_left, lo_right, hi_right)
-         */
-        for(l_ii=0; l_ii < l_to_read; l_ii++)
-        {
-           gap_audio_wav_write_gint16(fp_wav, *l_lptr);
-           l_lptr++;
-           if(l_audio_channels > 1)
-           {
-             gap_audio_wav_write_gint16(fp_wav, *l_rptr);
-             l_rptr++;
-           }
-         }
-      }
-
-
-      l_to_read = MIN(l_left_to_read, l_block_read);
-
-      /* calculate progress */
-      l_progress = (gdouble)(samples_to_read - l_left_to_read) / ((gdouble)samples_to_read + 1.0);
-      if(gap_debug) printf("l_progress:%f\n", (float)l_progress);
-      if (gpp->val.run_mode != GIMP_RUN_NONINTERACTIVE)
-      {
-        gimp_progress_update (l_progress);
-      }
-    }
-    if(wav_save) 
-    {
-      /* close wavfile */
-      fclose(fp_wav);
-    }
-
-    /* free audio buffers */
-    g_free(left_ptr);
-    g_free(right_ptr);
-  }
-#endif
-  return;
-}  /* end p_extract_audio */
 
+}  /* end p_frame_postprocessing  */
 
 
 /* ------------------------------
@@ -232,9 +189,10 @@ gap_vex_exe_extract_videorange(GapVexMainGlobalParams *gpp)
 
   l_overwrite_mode_audio = 0;
 
+
   if(gap_debug)
   {
-      printf("RUN p_mpg_fetch_range with parameters:\n");
+      printf("RUN gap_vex_exe_extract_videorange with parameters:\n");
       printf("videoname    : %s\n", gpp->val.videoname);
       printf("begin_percent: %f\n", (float)gpp->val.begin_percent);
       printf("end_percent  : %f\n", (float)gpp->val.end_percent);
@@ -255,6 +213,10 @@ gap_vex_exe_extract_videorange(GapVexMainGlobalParams *gpp)
       printf("exact_seek   : %d\n", (int)gpp->val.exact_seek);
       printf("deinterlace  : %d\n", (int)gpp->val.deinterlace);
       printf("delace_threshold: %f\n", (float)gpp->val.delace_threshold);
+
+      printf("generate_alpha_via_bluebox: %d\n", (int)gpp->val.generate_alpha_via_bluebox);
+      printf("extract_alpha_as_gray_frames: %d\n", (int)gpp->val.extract_alpha_as_gray_frames);
+      printf("extract_with_layermask: %d\n", (int)gpp->val.extract_with_layermask);
   }
 
   l_save_run_mode = GIMP_RUN_INTERACTIVE;  /* for the 1.st call of saving a non xcf frame */
@@ -281,8 +243,8 @@ gap_vex_exe_extract_videorange(GapVexMainGlobalParams *gpp)
      l_overwrite_mode_audio = 0;
      l_overwrite_mode_audio = gap_vex_dlg_overwrite_dialog(gpp
                                  , gpp->val.audiofile
-				 , l_overwrite_mode_audio
-				 );
+                                 , l_overwrite_mode_audio
+                                 );
   }
 
 
@@ -307,6 +269,7 @@ gap_vex_exe_extract_videorange(GapVexMainGlobalParams *gpp)
     l_pos_end  = (gpp->val.end_percent / 100.0);
     l_pos      = (gpp->val.begin_percent / 100.0);
     l_expected_frames = gvahand->total_frames * (l_pos_end - l_pos);
+
     framenumber1_delta = framenumber - (gvahand->total_frames * l_pos);
     if(gpp->val.basenum <= 0)
     {
@@ -347,7 +310,12 @@ gap_vex_exe_extract_videorange(GapVexMainGlobalParams *gpp)
      }
 
 
-    /* check if we need an INTERACTIVE Dummy save to set defaults for further save calls */
+    /* check if we need an INTERACTIVE Dummy save to set default parameters
+     * for further frame save operation.
+     * The dummy save is done at begin of processing
+     * because the handling of the 1st frame may
+     * occure after a significant delay, caused by seeking in large videofiles.
+     */
     if((strcmp(gpp->val.extension, ".xcf") == 0)
     || (strcmp(gpp->val.extension, ".XCF") == 0))
     {
@@ -372,14 +340,22 @@ gap_vex_exe_extract_videorange(GapVexMainGlobalParams *gpp)
       gap_layer_clear_to_color(l_empty_layer_id, 0.0, 0.0, 0.0, 1.0);
 
       l_save_run_mode = GIMP_RUN_INTERACTIVE;  /* for the 1.st call of saving a non xcf frame */
-      l_dummyname = gimp_temp_name(gpp->val.extension);
+
+      /* must use same basename and extension for the dummyname
+       * because setup of jpeg save params for further non interactive save operation
+       * depend on a key that includes the same basename and extension. 
+       */
+      l_dummyname = gap_lib_alloc_fname6(&gpp->val.basename[0]
+                                        ,99999999
+                                        ,&gpp->val.extension[0]
+                                        ,8  /* use full 8 digits for the numberpart */
+                                        );
       gimp_image_set_filename(l_dummy_image_id, l_dummyname);
-      gimp_file_save(l_save_run_mode
-                         ,l_dummy_image_id
-                         ,l_empty_layer_id
-                         ,l_dummyname
-                         ,l_dummyname
-                         );
+      gap_lib_save_named_image(l_dummy_image_id
+                           , l_dummyname
+                           , l_save_run_mode
+                           );
+
       gap_image_delete_immediate(l_dummy_image_id);
       g_remove(l_dummyname);                       
       g_free(l_dummyname);       
@@ -410,7 +386,7 @@ gap_vex_exe_extract_videorange(GapVexMainGlobalParams *gpp)
       else
       {
         /* dead code (older and slower seek emulation
-	 * implementation outside the API) 
+         * implementation outside the API) 
          */
         l_seek_framenumber = l_pos;
         if(l_pos_unit == GVA_UPOS_PRECENTAGE)
@@ -458,7 +434,7 @@ gap_vex_exe_extract_videorange(GapVexMainGlobalParams *gpp)
        if(gpp->val.multilayer == 0)
        {
          if((gpp->val.deinterlace == GAP_VEX_DELACE_ODD_X2) 
-	 || (gpp->val.deinterlace == GAP_VEX_DELACE_EVEN_X2))
+         || (gpp->val.deinterlace == GAP_VEX_DELACE_EVEN_X2))
          {
            framenumber_fil = (framenumber * 2) -1;
          }
@@ -491,20 +467,44 @@ gap_vex_exe_extract_videorange(GapVexMainGlobalParams *gpp)
            gpp->val.image_ID = gvahand->image_id;
 
            l_overwrite_mode = gap_vex_dlg_overwrite_dialog(gpp
-	                             , framename
-				     , l_overwrite_mode
-				     );
+                                     , framename
+                                     , l_overwrite_mode
+                                     );
            if (l_overwrite_mode < 0)
            {
                g_free(framename);       
                break;
            }
-           gimp_file_save(l_save_run_mode
-                         ,gvahand->image_id
-                         ,gvahand->layer_id
-                         ,framename
-                         ,framename
-                         );
+           else
+           {
+              gint32 l_sav_rc;
+              gint32 l_sav_image_id;
+              
+              l_sav_image_id = gvahand->image_id;
+              
+              p_frame_postprocessing(gvahand, gpp);
+              if (gpp->val.extract_alpha_as_gray_frames == TRUE)
+              {
+                l_sav_image_id = gimp_image_duplicate(gvahand->image_id);
+                gimp_image_convert_grayscale(l_sav_image_id);
+              }
+
+              l_sav_rc = gap_lib_save_named_image(l_sav_image_id
+                           , framename
+                           , l_save_run_mode
+                           );
+                           
+              if (l_sav_image_id != gvahand->image_id)
+              {
+                /* delete temporary grayscale image */
+                gap_image_delete_immediate(l_sav_image_id);
+              }
+              if (l_sav_rc < 0)
+              {
+                g_message(_("failed to save file:\n'%s'"), framename);
+                break;
+              }
+           }
            g_free(framename);       
          }
        }
@@ -517,6 +517,7 @@ gap_vex_exe_extract_videorange(GapVexMainGlobalParams *gpp)
                                        ,delace[0]
                                        ,gpp->val.delace_threshold
                                        );
+         p_frame_postprocessing(gvahand, gpp);
          if(l_rc != GVA_RET_OK)
          {
            break;
@@ -524,7 +525,7 @@ gap_vex_exe_extract_videorange(GapVexMainGlobalParams *gpp)
          gpp->val.image_ID = gvahand->image_id;
          
          if((gpp->val.deinterlace == GAP_VEX_DELACE_ODD_X2)
-	 || (gpp->val.deinterlace == GAP_VEX_DELACE_EVEN_X2))
+         || (gpp->val.deinterlace == GAP_VEX_DELACE_EVEN_X2))
          {
            /* deinterlace the other set of rows as extra layer (even/odd) */
            l_rc = GVA_frame_to_gimp_layer(gvahand
@@ -561,113 +562,42 @@ gap_vex_exe_extract_videorange(GapVexMainGlobalParams *gpp)
     }
   }
 
+
   /* ------ extract Audio ---------- */
   if((gvahand->atracks > 0)
   && (gpp->val.audiotrack > 0))
   {
      if (l_overwrite_mode_audio >= 0)
      {
-        gdouble l_samples_to_read;
-        gdouble l_extracted_frames;
+       gdouble l_extracted_frames;
+       gboolean do_progress;
+       
+       l_extracted_frames = framenumber - framenumber1;
+       
+       do_progress = TRUE;
+       if(gpp->val.run_mode != GIMP_RUN_NONINTERACTIVE)
+       {
+         do_progress = FALSE;
+       }
 
-        if(gap_debug) printf("EXTRACTING audio, writing to file %s\n", gpp->val.audiofile);
-
-        if (gpp->val.exact_seek != 0)
-        {
-          /* close and reopen to make sure that we start at begin */
-
-          gvahand->image_id = -1;   /* prenvent API from deleting that image at close */
-          GVA_close(gvahand);
-
-          /* --------- (RE)OPEN the videofile --------------- */
-          gvahand = GVA_open_read_pref(gpp->val.videoname
-                                   ,gpp->val.videotrack
-                                   ,gpp->val.audiotrack
-                                   ,gpp->val.preferred_decoder
-                                   , FALSE  /* use MMX if available (disable_mmx == FALSE) */
-                                   );
-          if(gvahand == NULL)
-          {
-             return;
-          }
-        }
-
-        if(gvahand->audio_cannels > 0)
-        {
-          /* seek needed only if extract starts not at pos 1 */
-          if(l_pos > 1)
-          {
-            if (gpp->val.run_mode != GIMP_RUN_NONINTERACTIVE)
-            {
-               gimp_progress_init (_("Seek Audio Position..."));
-            }
-
-            /* check for exact frame_seek */
-            if (gpp->val.exact_seek != 0)
-            {
-               gint32 l_seek_framenumber;
-               
-               
-               l_seek_framenumber = l_pos;
-               if(l_pos_unit == GVA_UPOS_PRECENTAGE)
-               {
-                 l_seek_framenumber = gvahand->total_frames * l_pos;
-               }
-               
-               l_samples_to_read = (gdouble)(l_seek_framenumber) 
-                                / (gdouble)gvahand->framerate * (gdouble)gvahand->samplerate;
-
-               /* extract just for exact positioning (without save to wav file) */
-               if(gap_debug) printf("extract just for exact positioning (without save to wav file)\n");
-               p_extract_audio(gpp, gvahand, l_samples_to_read,  FALSE);
-            }
-            else
-            {
-              /* audio pos 1 frame before video pos
-                * example: extract frame 1 upto 2
-                * results in audio range 0 upto 2
-                * this way we can get the audioduration of frame 1 
-                */
-               GVA_seek_audio(gvahand, l_pos -1, l_pos_unit);
-            }
-          }
-
-          if (gpp->val.run_mode != GIMP_RUN_NONINTERACTIVE)
-          {
-             gimp_progress_init (_("Extracting Audio..."));
-          }
-
-          l_extracted_frames = framenumber - framenumber1;
-          if(l_extracted_frames > 1)
-          {
-            l_samples_to_read = (gdouble)(l_extracted_frames +1.0)
-	                      / (gdouble)gvahand->framerate 
-			      * (gdouble)gvahand->samplerate;
-            if(gap_debug) printf("A: l_samples_to_read %.0f l_extracted_frames:%d\n"
-	                         , (float)l_samples_to_read
-				 ,(int)l_extracted_frames
-				 );
-          }
-          else
-          {
-            l_samples_to_read = (gdouble)(l_expected_frames +1.0) 
-	                      / (gdouble)gvahand->framerate 
-			      * (gdouble)gvahand->samplerate;
-            if(gap_debug) printf("B: l_samples_to_read %.0f l_extracted_frames:%d l_expected_frames:%d\n"
-	                        , (float)l_samples_to_read
-				,(int)l_extracted_frames
-				,(int)l_expected_frames
-				);
-          }
-
-          /* extract and save to wav file */
-          if(gap_debug) printf("extract (with save to wav file)\n");
-          p_extract_audio(gpp, gvahand, l_samples_to_read,  TRUE);
-        }
-        
+       gap_audio_extract_from_videofile(gpp->val.videoname
+             , gpp->val.audiofile
+             , gpp->val.audiotrack
+             , gpp->val.preferred_decoder
+             , gpp->val.exact_seek
+             , l_pos_unit
+             , l_pos
+             , l_extracted_frames
+             , l_expected_frames
+             , do_progress
+             , NULL         /* GtkWidget *progressBar  using NULL for gimp_progress */
+             , NULL         /* fptr_progress_callback */
+             , NULL         /* user_data */
+             );
      }
   }
 
+
   if((gpp->val.image_ID >= 0)
   && (gpp->val.multilayer == 0)
   && (gpp->val.videotrack > 0))
@@ -685,6 +615,7 @@ gap_vex_exe_extract_videorange(GapVexMainGlobalParams *gpp)
   
   if(gpp->val.image_ID >= 0)
   {
+    gimp_image_undo_enable(gpp->val.image_ID);
     gimp_display_new(gpp->val.image_ID);
     gimp_displays_flush();
     gvahand->image_id = -1;   /* prenvent API from deleting that image at close */
